@@ -105,9 +105,9 @@ public:
   void collectColours(const std::vector<Colour> &colours);
   void collectFont(unsigned short fontID, const WPXBinaryData &textStream, TextFormat format);
   void collectText(unsigned id, unsigned level, const WPXBinaryData &textStream, TextFormat format);
-  void collectVSDXCharStyle(unsigned id , unsigned level, unsigned charCount, unsigned short fontID, Colour fontColour, unsigned langId,
-                            double fontSize, bool bold, bool italic, bool underline, bool doubleunderline, bool strikeout, bool doublestrikeout,
-                            bool allcaps, bool initcaps, bool smallcaps, bool superscript, bool subscript, WPXString fontFace);
+  void collectVSDXCharStyle(unsigned id , unsigned level, unsigned charCount, unsigned short fontID, Colour fontColour, double fontSize,
+                            bool bold, bool italic, bool underline, bool doubleunderline, bool strikeout, bool doublestrikeout,
+                            bool allcaps, bool initcaps, bool smallcaps, bool superscript, bool subscript, VSDXFont fontFace);
   void collectVSDXParaStyle(unsigned id , unsigned level, unsigned charCount, double indFirst, double indLeft, double indRight,
                             double spLine, double spBefore, double spAfter, unsigned char align, unsigned flags);
   void collectTextBlock(unsigned id, unsigned level, double leftMargin, double rightMargin, double topMargin, double bottomMargin, unsigned char verticalAlign,
@@ -124,9 +124,9 @@ public:
                         double shadowOffsetX, double shadowOffsetY);
   void collectFillStyle(unsigned id, unsigned level, unsigned char colourIndexFG, unsigned char colourIndexBG, unsigned char fillPattern,
                         unsigned char fillFGTransparency, unsigned char fillBGTransparency, unsigned char shadowPattern, Colour shfgc);
-  void collectCharIXStyle(unsigned id , unsigned level, unsigned charCount, unsigned short fontID, Colour fontColour, unsigned langId,
-                          double fontSize, bool bold, bool italic, bool underline, bool doubleunderline, bool strikeout, bool doublestrikeout,
-                          bool allcaps, bool initcaps, bool smallcaps, bool superscript, bool subscript, WPXString fontFace);
+  void collectCharIXStyle(unsigned id , unsigned level, unsigned charCount, unsigned short fontID, Colour fontColour, double fontSize,
+                          bool bold, bool italic, bool underline, bool doubleunderline, bool strikeout, bool doublestrikeout,
+                          bool allcaps, bool initcaps, bool smallcaps, bool superscript, bool subscript, VSDXFont fontFace);
   void collectParaIXStyle(unsigned id , unsigned level, unsigned charCount, double indFirst, double indLeft, double indRight,
                           double spLine, double spBefore, double spAfter, unsigned char align, unsigned flags);
   void collectTextBlockStyle(unsigned id, unsigned level, double leftMargin, double rightMargin, double topMargin, double bottomMargin, unsigned char verticalAlign,
@@ -139,7 +139,7 @@ public:
 
   void startPage();
   void endPage();
-  void endPages();
+  void endPages(const std::vector<unsigned> &pageOrder);
 
 
 private:
@@ -161,8 +161,6 @@ private:
   void _flushCurrentPage();
 
   void _handleLevelChange(unsigned level);
-  void _appendUTF16LE(WPXString &text, WPXInputStream *input);
-  void _appendUCS4(WPXString &text, unsigned ucs4Character);
 
   void _handleForeignData(const WPXBinaryData &data);
 
@@ -173,10 +171,15 @@ private:
 
   void _applyLinePattern();
   void _lineProperties(double strokeWidth, Colour c, unsigned linePattern, unsigned startMarker, unsigned endMarker, unsigned lineCap);
+  const char *_linePropertiesMarkerViewbox(unsigned marker);
+  const char *_linePropertiesMarkerPath(unsigned marker);
+  double _linePropertiesMarkerScale(unsigned marker);
   void _fillAndShadowProperties(unsigned colourIndexFG, unsigned colourIndexBG, unsigned fillPattern,
                                 unsigned fillFGTransparency, unsigned fillBGTransparency,
                                 unsigned shadowPattern, Colour shfgc, double shadowOffsetX, double shadowOffsetY);
 
+  void appendCharacters(WPXString &text, const std::vector<unsigned char> &characters, TextFormat format);
+  void appendCharacters(WPXString &text, const std::vector<unsigned char> &characters);
   void _convertDataToString(WPXString &result, const WPXBinaryData &data, TextFormat format);
   bool parseFormatId( const char *formatString, unsigned short &result );
 
@@ -192,7 +195,8 @@ private:
   double m_originalY;
   XForm m_xform;
   XForm *m_txtxform;
-  std::vector<WPXPropertyList> m_currentGeometry;
+  std::vector<WPXPropertyList> m_currentFillGeometry;
+  std::vector<WPXPropertyList> m_currentLineGeometry;
   std::map<unsigned, XForm> &m_groupXForms;
   WPXBinaryData m_currentForeignData;
   WPXBinaryData m_currentOLEData;
@@ -215,7 +219,7 @@ private:
   bool m_noFill;
   bool m_noShow;
   std::vector<Colour> m_colours;
-  std::map<unsigned short, WPXString> m_fonts;
+  std::map<unsigned short, VSDXFont> m_fonts;
   unsigned m_currentLevel;
   bool m_isShapeStarted;
   std::map<unsigned, unsigned> &m_groupMemberships;
