@@ -238,15 +238,15 @@ void libvisio::VSDXStylesCollector::collectText(unsigned /*id*/, unsigned level,
 }
 
 void libvisio::VSDXStylesCollector::collectVSDXParaStyle(unsigned /* id */ , unsigned level, unsigned /* charCount */, double /* indFirst */, double /* indLeft */,
-    double /* indRight */, double /* spLine */, double /* spBefore */, double /* spAfter */, unsigned char /* align */)
+    double /* indRight */, double /* spLine */, double /* spBefore */, double /* spAfter */, unsigned char /* align */, unsigned /* flags */)
 {
   _handleLevelChange(level);
 }
 
-void libvisio::VSDXStylesCollector::collectVSDXCharStyle(unsigned /*id*/ , unsigned level, unsigned /*charCount*/, unsigned short /*fontID*/, Colour /*fontColour*/,
-    unsigned /*langId*/, double /*fontSize*/, bool /*bold*/, bool /*italic*/, bool /*underline*/,
+void libvisio::VSDXStylesCollector::collectVSDXCharStyle(unsigned /*id*/ , unsigned level, unsigned /*charCount*/, unsigned short /*fontID*/,
+    Colour /*fontColour*/, double /*fontSize*/, bool /*bold*/, bool /*italic*/, bool /*underline*/,
     bool /* doubleunderline */, bool /* strikeout */, bool /* doublestrikeout */, bool /* allcaps */,
-    bool /* initcaps */, bool /* smallcaps */, bool /* superscript */, bool /* subscript */, WPXString /*fontFace*/)
+    bool /* initcaps */, bool /* smallcaps */, bool /* superscript */, bool /* subscript */, VSDXFont /*fontFace*/)
 {
   _handleLevelChange(level);
 }
@@ -316,22 +316,22 @@ void libvisio::VSDXStylesCollector::collectFillStyle(unsigned /*id*/, unsigned l
 }
 
 void libvisio::VSDXStylesCollector::collectParaIXStyle(unsigned /*id*/, unsigned level, unsigned charCount, double indFirst, double indLeft, double indRight,
-    double spLine, double spBefore, double spAfter, unsigned char align)
+    double spLine, double spBefore, double spAfter, unsigned char align, unsigned flags)
 {
   _handleLevelChange(level);
   if (!m_paraStyle)
-    m_paraStyle = new VSDXParaStyle(charCount, indFirst, indLeft, indRight, spLine, spBefore, spAfter, align);
+    m_paraStyle = new VSDXParaStyle(charCount, indFirst, indLeft, indRight, spLine, spBefore, spAfter, align, flags);
 }
 
 
-void libvisio::VSDXStylesCollector::collectCharIXStyle(unsigned /*id*/ , unsigned level, unsigned charCount, unsigned short fontID, Colour fontColour,
-    unsigned langID, double fontSize, bool bold, bool italic, bool underline, bool doubleunderline,
+void libvisio::VSDXStylesCollector::collectCharIXStyle(unsigned /*id*/ , unsigned level, unsigned charCount, unsigned short fontID,
+    Colour fontColour, double fontSize, bool bold, bool italic, bool underline, bool doubleunderline,
     bool strikeout, bool doublestrikeout, bool allcaps, bool initcaps, bool smallcaps,
-    bool superscript, bool subscript, WPXString fontFace)
+    bool superscript, bool subscript, VSDXFont fontFace)
 {
   _handleLevelChange(level);
   if (!m_charStyle)
-    m_charStyle = new VSDXCharStyle(charCount, fontID, fontColour, langID, fontSize, bold, italic, underline, doubleunderline, strikeout, doublestrikeout,
+    m_charStyle = new VSDXCharStyle(charCount, fontID, fontColour, fontSize, bold, italic, underline, doubleunderline, strikeout, doublestrikeout,
                                     allcaps, initcaps, smallcaps, superscript, subscript, fontFace);
 }
 
@@ -378,19 +378,19 @@ void libvisio::VSDXStylesCollector::endPage()
   _handleLevelChange(0);
   m_groupXFormsSequence.push_back(m_groupXForms);
   m_groupMembershipsSequence.push_back(m_groupMemberships);
-  while (m_groupShapeOrder.size())
+  while (!m_groupShapeOrder.empty())
   {
     for (std::list<unsigned>::iterator j = m_pageShapeOrder.begin(); j != m_pageShapeOrder.end();)
     {
       std::map<unsigned, std::list<unsigned> >::iterator iter = m_groupShapeOrder.find(*j);
       if (m_groupShapeOrder.end() != iter)
       {
-        j++;
+        ++j;
         m_pageShapeOrder.splice(j, iter->second, iter->second.begin(), iter->second.end());
         m_groupShapeOrder.erase(iter);
       }
       else
-        j++;
+        ++j;
     }
   }
   m_documentPageShapeOrders.push_back(m_pageShapeOrder);
@@ -441,7 +441,7 @@ void libvisio::VSDXStylesCollector::_handleLevelChange(unsigned level)
 
 void libvisio::VSDXStylesCollector::_flushShapeList()
 {
-  if (!m_shapeList.size())
+  if (m_shapeList.empty())
     return;
 
   if (m_isShapeStarted)
